@@ -30,6 +30,8 @@ class Decompressor():
                     
             await asyncio.gather(*tasks)
 
+        cleanup(local_temp_dir)
+
     async def process_blob_file(self, container_name, blob_client, dest_dir, local_file):
         print(f"start processing file: {local_file}")
 
@@ -88,4 +90,7 @@ class Decompressor():
             os.makedirs(local_temp_dir)
         except OSError as exc: # Guard against race condition
             if exc.errno != errno.EEXIST:
-                raise      
\ No newline at end of file
+                raise      
+
+    def cleanup(local_temp_dir):
+        shutil.rmtree(local_temp_dir)
\ No newline at end of file
